aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/platforms/STM32/GPIOv1/pal_lld.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/platforms/STM32/GPIOv1/pal_lld.h')
-rw-r--r--os/hal/platforms/STM32/GPIOv1/pal_lld.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/os/hal/platforms/STM32/GPIOv1/pal_lld.h b/os/hal/platforms/STM32/GPIOv1/pal_lld.h
index ab1c273bc..ce0525fd6 100644
--- a/os/hal/platforms/STM32/GPIOv1/pal_lld.h
+++ b/os/hal/platforms/STM32/GPIOv1/pal_lld.h
@@ -199,7 +199,7 @@ typedef GPIO_TypeDef * ioportid_t;
* @note This function is not meant to be invoked directly by the application
* code.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The port bits.
*
* @notapi
@@ -213,7 +213,7 @@ typedef GPIO_TypeDef * ioportid_t;
* @note This function is not meant to be invoked directly by the application
* code.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The latched logical states.
*
* @notapi
@@ -228,8 +228,8 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] bits the bits to be written on the specified port
+ * @param[in] port port identifier
+ * @param[in] bits bits to be written on the specified port
*
* @notapi
*/
@@ -243,8 +243,8 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] bits the bits to be ORed on the specified port
+ * @param[in] port port identifier
+ * @param[in] bits bits to be ORed on the specified port
*
* @notapi
*/
@@ -258,8 +258,8 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] bits the bits to be cleared on the specified port
+ * @param[in] port port identifier
+ * @param[in] bits bits to be cleared on the specified port
*
* @notapi
*/
@@ -273,10 +273,10 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] mask the group mask
+ * @param[in] port port identifier
+ * @param[in] mask group mask
* @param[in] offset the group bit offset within the port
- * @param[in] bits the bits to be written. Values exceeding the group
+ * @param[in] bits bits to be written. Values exceeding the group
* width are masked.
*
* @notapi
@@ -293,14 +293,15 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
* @param[in] port the port identifier
* @param[in] mask the group mask
* @param[in] mode the mode
*
* @notapi
*/
-#define pal_lld_setgroupmode(port, mask, mode) \
- _pal_lld_setgroupmode(port, mask, mode)
+#define pal_lld_setgroupmode(port, mask, offset, mode) \
+ _pal_lld_setgroupmode(port, mask << offset, mode)
/**
* @brief Writes a logical state on an output pad.
@@ -308,8 +309,8 @@ typedef GPIO_TypeDef * ioportid_t;
* effect to modify the resistor setting because the output latched
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] pad the pad number within the port
+ * @param[in] port port identifier
+ * @param[in] pad pad number within the port
* @param[in] bit logical value, the value must be @p PAL_LOW or
* @p PAL_HIGH
*
@@ -293,14 +293,15 @@ typedef GPIO_TypeDef * ioportid_t;
* data is used for the resistor selection.
*
- * @param[in] port the port identifier
- * @param[in] mask the group mask
- * @param[in] mode the mode
+ * @param[in] port port identifier
+ * @param[in] mask group mask
+ * @param[in] offset group bit offset within the port
+ * @param[in] mode group mode
*
* @notapi